import ajax from '../util/ajax'
import api from '../util/api'

export default {
  namespaced: true,
  state: {
    menuData: [],
    userInfo: {},
    isBind: false,
    meta: null
  },
  mutations: {
    updateMenu (state, data) {
      state.menuData = data || []
    },
    updateUserInfo (state, data) {
      state.userInfo = data || {}
    },
    updateIsBind (state, data) {
      state.isBind = data
    },
    updateMeta (state, data) {
      state.meta = data
    }
  },
  actions: {
    login (context, data) {
      context
      return new Promise((resolve, reject) => {
        ajax({
          ...api.common.login,
          data: {
            ...data,
          }
        }).then(() => {
          resolve()
        }).catch(reject)
      })
    },
    logOut (context) {
      context
      return new Promise((resolve, reject) => {
        ajax({
          ...api.common.logOut
        }).then(() => {
          resolve()
        }).catch(reject)
      })
    },
    getMainMenu (context, data) {
      return new Promise((resolve, reject) => {
        ajax({
          ...api.common.menu,
          data: {
            ...data,
          }
        }).then((res) => {
          context.commit('updateMenu', res)
          resolve()
        }).catch(reject)
      })
    },
    clearMenu (context) {
      context.commit('updateMenu', '')
    },
    getUserInfo (context) {
      return new Promise((resolve, reject) => {
        ajax({
          ...api.user.getUserInfo
        }).then((res) => {
          context.commit('updateUserInfo', res)
          resolve()
        }).catch(reject)
      })
    },
    changePassWord (context, data) {
      context
      return new Promise((resolve, reject) => {
        ajax({
          ...api.user.changePassWord,
          data: {
            ...data
          }
        }).then(() => {
          resolve()
        }).catch(reject)
      })
    },
    checkBind (context) {
      return new Promise((resolve, reject) => {
        ajax({
          ...api.common.checkBind
        }).then((res) => {
          context.commit('updateIsBind', res)
          resolve()
        }).catch(reject)
      })
    },
    setMeta (context, data) {
      context.commit('updateMeta', data)

    }
  }
}
