import ajax from '../util/ajax'
import api from '../util/api'

export default {
  namespaced: true,
  state: {
    managementList: [],
    current: 1,
    total: 0,
    authData: {},
    wechatConfig: {}
  },
  mutations: {
    updateManagementList (state, data) {
      state.managementList = data.list || []
      state.total = data.pagenum
    },
    updateCurrent (state, data) {
      state.current = data
    },
    updateAuthData (state, data) {
      state.authData = data || {}
    },
    updateWechatConfig (state, data) {
      state.wechatConfig = data
    },
  },
  actions: {
    getManagementList (context, data) {
      return new Promise((resolve, reject) => {
        ajax({
          ...api.management.getManagementList,
          queryData: {
            ...data
          }
        }).then((res) => {
          context.commit('updateManagementList', res)
          resolve()
        }).catch(reject)
      })
    },
    addManagement (context, data) {
      console.log(context)
      return new Promise((resolve, reject) => {
        ajax({
          ...api.management.addManagement,
          data: {
            ...data
          }
        }).then(() => {
          resolve()
        }).catch(reject)
      })
    },
    deleteManagement (context, data) {
      console.log(context)
      return new Promise((resolve, reject) => {
        ajax({
          ...api.management.deleteManagement,
          urlData: {
            ...data
          }
        }).then(() => {
          resolve()
        }).catch(reject)
      })
    },
    changeCurrent (context, data) {
      context.commit('updateCurrent', data)
    },
    authcode (context) {
      return new Promise((resolve, reject) => {
        ajax({
          ...api.management.authcode
        }).then((res) => {
          context.commit('updateAuthData', res)
          resolve()
        }).catch(reject)
      })
    },
    setAuthcode (context, data) {
      console.log(context)
      return new Promise((resolve, reject) => {
        ajax({
          ...api.management.setAuthcode,
          urlData: {
            ...data
          }
        }).then((res) => {
          context.commit('updateWechatConfig', res)
          resolve()
        }).catch(reject)
      })
    },
    checkAuth (context, data) {
      console.log(context)
      return new Promise((resolve, reject) => {
        ajax({
          ...api.management.checkAuth,
          urlData: {
            ...data
          }
        }).then(() => {
          resolve()
        }).catch(reject)
      })
    }
  }
}
