import ajax from '../util/ajax'
import api from '../util/api'

export default {
  namespaced: true,
  state: {
    userList: [],
    current: 1,
    total: 0,
    projectList: [],
    oldInfo: {}
  },
  mutations: {
    updateUserList (state, data) {
      state.userList = data.list || []
      state.total = data.pagenum
    },
    updateCurrent (state, data) {
      state.current = data
    },
    updateSysuserInfo (state, data) {
      state.oldInfo = data
    },
    updateProjectList (state, data) {
      state.projectList = data.list || []
    },
  },
  actions: {
    getUserList (context, data) {
      return new Promise((resolve, reject) => {
        ajax({
          ...api.user.getUserList,
          queryData: {
            ...data
          }
        }).then((res) => {
          context.commit('updateUserList', res)
          resolve()
        }).catch(reject)
      })
    },
    changeCurrent(context, data){
      context.commit('updateCurrent', data)
    },
    addUser (context, data) {
      return new Promise((resolve, reject) => {
        ajax({
          ...api.user.addUser,
          data:{
            ...data
          }
        }).then((res) => {
          console.log(res)
          resolve()
        }).catch(reject)
      })
    },
    editUser (context, data) {
      return new Promise((resolve, reject) => {
        ajax({
          ...api.user.editUser,
          data: {
            ...data
          }
        }).then((res) => {
          console.log(res)
          resolve()
        }).catch(reject)
      })
    },
    getSysuserInfo (context, data) {
      return new Promise((resolve, reject) => {
        ajax({
          ...api.user.getSysuserInfo,
          urlData:{
            ...data
          }
        }).then((res) => {
          context.commit('updateSysuserInfo', res)
          resolve(res)
        }).catch(reject)
      })
    },
    getProjectList (context) {
      return new Promise((resolve, reject) => {
        ajax({
          ...api.common.getProjectList,
          queryData: {
            page: 1,
            pagesize: 10000
          }
        }).then((res) => {
          context.commit('updateProjectList', res)
          resolve(res)
        }).catch(reject)
      })
    },
    BindProject (context, data) {
      console.log(context)
      return new Promise((resolve, reject) => {
        ajax({
          ...api.user.BindProject,
          urlData: { ...data }
        }).then(() => {
          resolve()
        }).catch(reject)
      })
    },
    UnBindProject (context, data) {
      console.log(context)
      return new Promise((resolve, reject) => {
        ajax({
          ...api.user.UnBindProject,
          urlData: { ...data }
        }).then(() => {
          resolve()
        }).catch(reject)
      })
    }
  }
}
